==> jc-1.4.0.tar.gz: gnu/java/nio/ServerSocketChannelImpl.h <==
// public final class gnu.java.nio.ServerSocketChannelImpl

// class file dependencies
// @dep_class 27d7166a0afe8bf8 gnu_java_nio_ServerSocketChannelImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class bb82468336bc847b java_nio_channels_ServerSocketChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_ServerSocketChannel

#include "java/nio/channels/ServerSocketChannel.h"

#ifndef _JC_gnu_java_nio_ServerSocketChannelImpl_H_
#define _JC_gnu_java_nio_ServerSocketChannelImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_NIOServerSocket$object;
struct _jc_java_lang_Class$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs	_jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs	_jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$refs	_jc_gnu_java_nio_ServerSocketChannelImpl$refs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs	_jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$object	_jc_gnu_java_nio_ServerSocketChannelImpl$object;

typedef const struct _jc_gnu_java_nio_ServerSocketChannelImpl$vmethods	_jc_gnu_java_nio_ServerSocketChannelImpl$vmethods;
typedef const struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtable	_jc_gnu_java_nio_ServerSocketChannelImpl$vtable;
typedef const struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtype	_jc_gnu_java_nio_ServerSocketChannelImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_gnu_java_nio_ServerSocketChannelImpl$method$accept$f9d2887ca9e9341b(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$finalizer$f3a1048c43ea524b(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
extern jint _jc_gnu_java_nio_ServerSocketChannelImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$implCloseSelectableChannel$315f020e75eca883(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$implConfigureBlocking$a0eca1c8bc794f2a(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *, jboolean);
extern struct _jc_java_net_ServerSocket$object *_jc_gnu_java_nio_ServerSocketChannelImpl$method$socket$ca2d30a396954881(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$accept$f9d2887ca9e9341b;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$finalizer$f3a1048c43ea524b;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$implCloseSelectableChannel$315f020e75eca883;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$implConfigureBlocking$a0eca1c8bc794f2a;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$socket$ca2d30a396954881;

// Virtual methods structure
struct _jc_gnu_java_nio_ServerSocketChannelImpl$vmethods {
	struct _jc_java_nio_channels_SocketChannel$object	*(*accept$f9d2887ca9e9341b)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
	void	(*finalizer$f3a1048c43ea524b)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
	void	(*implCloseSelectableChannel$315f020e75eca883)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
	void	(*implConfigureBlocking$a0eca1c8bc794f2a)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *, jboolean);
	struct _jc_java_net_ServerSocket$object	*(*socket$ca2d30a396954881)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *);
};

// Vtable
struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_ServerSocketChannel$vmethods	java_nio_channels_ServerSocketChannel;
	_jc_gnu_java_nio_ServerSocketChannelImpl$vmethods	gnu_java_nio_ServerSocketChannelImpl;
};

// Vtype
struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ServerSocketChannelImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs {
	struct _jc_gnu_java_nio_NIOServerSocket$object	*serverSocket;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$refs {
    _jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs	gnu_java_nio_ServerSocketChannelImpl;
    _jc_java_nio_channels_ServerSocketChannel$sub_refs	java_nio_channels_ServerSocketChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs {
	jboolean	connected;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs	java_nio_channels_ServerSocketChannel;
    _jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs	gnu_java_nio_ServerSocketChannelImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_ServerSocketChannelImpl$object {
	_jc_gnu_java_nio_ServerSocketChannelImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ServerSocketChannelImpl$vtype	*vtype;
	_jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ServerSocketChannelImpl$vtype _jc_gnu_java_nio_ServerSocketChannelImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ServerSocketChannelImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ServerSocketChannelImpl$class_object;

#endif	/* _JC_gnu_java_nio_ServerSocketChannelImpl_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/ServerSocketChannelImpl.h <==
// public final class gnu.java.nio.ServerSocketChannelImpl

// class file dependencies
// @dep_class 27d7166a0afe8bf8 gnu_java_nio_ServerSocketChannelImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class bb82468336bc847b java_nio_channels_ServerSocketChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_ServerSocketChannel

#include "java/nio/channels/ServerSocketChannel.h"

#ifndef _JC_gnu_java_nio_ServerSocketChannelImpl_H_
#define _JC_gnu_java_nio_ServerSocketChannelImpl_H_

// Forward structure declarations
struct _jc_gnu_java_nio_NIOServerSocket$object;
struct _jc_java_lang_Class$object;
struct _jc_java_net_ServerSocket$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs	_jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs	_jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$refs	_jc_gnu_java_nio_ServerSocketChannelImpl$refs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs	_jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs;
typedef struct _jc_gnu_java_nio_ServerSocketChannelImpl$object	_jc_gnu_java_nio_ServerSocketChannelImpl$object;

typedef const struct _jc_gnu_java_nio_ServerSocketChannelImpl$vmethods	_jc_gnu_java_nio_ServerSocketChannelImpl$vmethods;
typedef const struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtable	_jc_gnu_java_nio_ServerSocketChannelImpl$vtable;
typedef const struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtype	_jc_gnu_java_nio_ServerSocketChannelImpl$vtype;

// Constructors
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_gnu_java_nio_ServerSocketChannelImpl$method$accept$f9d2887ca9e9341b(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$finalizer$f3a1048c43ea524b(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_nio_ServerSocketChannelImpl$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$implCloseSelectableChannel$315f020e75eca883(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_ServerSocketChannelImpl$method$implConfigureBlocking$a0eca1c8bc794f2a(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_net_ServerSocket$object *_jc_gnu_java_nio_ServerSocketChannelImpl$method$socket$ca2d30a396954881(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$accept$f9d2887ca9e9341b;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$finalizer$f3a1048c43ea524b;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$getNativeFD$4ed008ed25fb0a89;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$implCloseSelectableChannel$315f020e75eca883;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$implConfigureBlocking$a0eca1c8bc794f2a;
extern _jc_method _jc_gnu_java_nio_ServerSocketChannelImpl$method_info$socket$ca2d30a396954881;

// Virtual methods structure
struct _jc_gnu_java_nio_ServerSocketChannelImpl$vmethods {
	struct _jc_java_nio_channels_SocketChannel$object	*(*accept$f9d2887ca9e9341b)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*finalizer$f3a1048c43ea524b)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*implCloseSelectableChannel$315f020e75eca883)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
	void	(*implConfigureBlocking$a0eca1c8bc794f2a)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *, jboolean) _JC_JCNI_ATTR;
	struct _jc_java_net_ServerSocket$object	*(*socket$ca2d30a396954881)(_jc_env *, struct _jc_gnu_java_nio_ServerSocketChannelImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_ServerSocketChannel$vmethods	java_nio_channels_ServerSocketChannel;
	_jc_gnu_java_nio_ServerSocketChannelImpl$vmethods	gnu_java_nio_ServerSocketChannelImpl;
};

// Vtype
struct _jc_gnu_java_nio_ServerSocketChannelImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ServerSocketChannelImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs {
	struct _jc_gnu_java_nio_NIOServerSocket$object	*serverSocket;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$refs {
    _jc_gnu_java_nio_ServerSocketChannelImpl$sub_refs	gnu_java_nio_ServerSocketChannelImpl;
    _jc_java_nio_channels_ServerSocketChannel$sub_refs	java_nio_channels_ServerSocketChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs {
	jboolean	connected;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_ServerSocketChannel$sub_nonrefs	java_nio_channels_ServerSocketChannel;
    _jc_gnu_java_nio_ServerSocketChannelImpl$sub_nonrefs	gnu_java_nio_ServerSocketChannelImpl;
};

// Object instance structure
struct _jc_gnu_java_nio_ServerSocketChannelImpl$object {
	_jc_gnu_java_nio_ServerSocketChannelImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ServerSocketChannelImpl$vtype	*vtype;
	_jc_gnu_java_nio_ServerSocketChannelImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ServerSocketChannelImpl$vtype _jc_gnu_java_nio_ServerSocketChannelImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ServerSocketChannelImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ServerSocketChannelImpl$class_object;

#endif	/* _JC_gnu_java_nio_ServerSocketChannelImpl_H_ */
